@@ -17,7 +17,7 @@ from typing import Text, Any, Dict, Union, List, Type, Callable
 
 import ruamel.yaml as yaml
 
-from rasa.constants import ENV_LOG_LEVEL, DEFAULT_LOG_LEVEL
+from rasa.constants import ENV_LOG_LEVEL, DEFAULT_LOG_LEVEL, YAML_VERSION
 
 if typing.TYPE_CHECKING:
     from prompt_toolkit.validation import Validator
@@ -110,27 +110,25 @@ def read_yaml(content: Text) -> Union[List[Any], Dict[Text, Any]]:
     replace_environment_variables()
 
     yaml_parser = yaml.YAML(typ="safe")
-    yaml_parser.version = "1.2"
-    yaml_parser.unicode_supplementary = True
+    yaml_parser.version = YAML_VERSION
 
-    # noinspection PyUnresolvedReferences
-    try:
-        return yaml_parser.load(content) or {}
-    except yaml.scanner.ScannerError:
-        # A `ruamel.yaml.scanner.ScannerError` might happen due to escaped
-        # unicode sequences that form surrogate pairs. Try converting the input
-        # to a parsable format based on
-        # https://stackoverflow.com/a/52187065/3429596.
+    if _is_ascii(content):
+        # Required to make sure emojis are correctly parsed
         content = (
             content.encode("utf-8")
             .decode("raw_unicode_escape")
             .encode("utf-16", "surrogatepass")
             .decode("utf-16")
         )
-        return yaml_parser.load(content) or {}
+
+    return yaml_parser.load(content) or {}
 
 
-def read_file(filename: Text, encoding: Text = DEFAULT_ENCODING) -> Any:
+def _is_ascii(text: Text) -> bool:
+    return all(ord(character) < 128 for character in text)
+
+
+def read_file(filename: Union[Text, Path], encoding: Text = DEFAULT_ENCODING) -> Any:
     """Read text from a file."""
 
     try:
@@ -140,7 +138,7 @@ def read_file(filename: Text, encoding: Text = DEFAULT_ENCODING) -> Any:
         raise ValueError(f"File '{filename}' does not exist.")
 
 
-def read_json_file(filename: Text) -> Any:
+def read_json_file(filename: Union[Text, Path]) -> Any:
     """Read json from a file."""
     content = read_file(filename)
     try:
@@ -152,7 +150,7 @@ def read_json_file(filename: Text) -> Any:
         )
 
 
-def dump_obj_as_json_to_file(filename: Text, obj: Any) -> None:
+def dump_obj_as_json_to_file(filename: Union[Text, Path], obj: Any) -> None:
     """Dump an object as a json string to a file."""
 
     write_text_file(json.dumps(obj, indent=2), filename)
